<?php

namespace App\Services\Traits;

use App\Exceptions\ServerRunTimeException;
use App\Repositories\Criteria\BaseCriteria;
use App\Services\AuthService as adminAuth;
use App\Services\Traits\DataEntriesService;
use App\Services\YyBao\Auth\AuthService as frontAuth;
use App\Services\YyBao\CustomersService;
use App\Services\YyBao\ImportExportTasksService;
use Illuminate\Support\Facades\DB;

trait BaseService
{
    protected $repository;
    protected $guard;

    public function setRepository($repository)
    {
        $this->repository = $repository;
    }

    public function getRepository()
    {
        return $this->repository;
    }

    public function setGuard($guardName)
    {
        $this->guard = $guardName;
    }

    public function getGuard()
    {
        return $this->guard;
    }

    public function moneyFromat($money, $fromat = true)
    {
        $money = bcdiv($money, 100 ,2);
        if($fromat){
            return is_numeric($money) ? sprintf("%.2f", substr(sprintf("%.3f", $money), 0, -1)) : '';
        }
        return $money;
    }

    public function getList($requestParams, BaseCriteria $pushCriteria)
    {
        $this->getRepository()->pushCriteria($pushCriteria);
        if(empty($requestParams['page_size']) || $requestParams['page_size'] == 0){
            $requestParams['page_size'] = 10;
        }
        return $this->getRepository()->listPageByPaginate($requestParams['page_size']);
    }

    public function collectionToArray($collection, $model = null)
    {
        return $this->getRepository()->transformData(
            collect($collection)->map(function($collect){
                return !is_array($collect) ? $collect->toArray() : $collect;
            }), $model
        );
    }

}
